aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrGpuResource.h
diff options
context:
space:
mode:
authorGravatar bsalomon <bsalomon@google.com>2015-02-19 07:24:21 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2015-02-19 07:24:21 -0800
commit8718aafec239c93485e45bbe8fed19d9a8def079 (patch)
tree209402fb1f20c023f822b4af7dd4212e44956821 /include/gpu/GrGpuResource.h
parent2e4414e60b1f98e1736aa1925cbe181ed37d11e8 (diff)
Rename GrContentKey to GrUniqueKey
Diffstat (limited to 'include/gpu/GrGpuResource.h')
-rw-r--r--include/gpu/GrGpuResource.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/gpu/GrGpuResource.h b/include/gpu/GrGpuResource.h
index aefae27dd5..80b50e308e 100644
--- a/include/gpu/GrGpuResource.h
+++ b/include/gpu/GrGpuResource.h
@@ -127,7 +127,7 @@ public:
enum LifeCycle {
/**
* The resource is cached and owned by Skia. Resources with this status may be kept alive
* by the cache as either scratch or content resources even when there are no refs to them.
* The cache may release them whenever there are no refs.
*/
kCached_LifeCycle,
@@ -187,9 +187,9 @@ public:
*/
uint32_t getUniqueID() const { return fUniqueID; }
- /** Returns the current content key for the resource. It will be invalid if the resource has not
- been cached by its contents. */
- const GrContentKey& getContentKey() const { return fContentKey; }
+ /** Returns the current unique key for the resource. It will be invalid if the resource has no
+ associated unique key. */
+ const GrUniqueKey& getUniqueKey() const { return fUniqueKey; }
/**
* Attach a custom data object to this resource. The data will remain attached
@@ -269,8 +269,8 @@ private:
virtual size_t onGpuMemorySize() const = 0;
// See comments in CacheAccess and ResourcePriv.
- bool setContentKey(const GrContentKey& contentKey);
- void removeContentKey();
+ bool setUniqueKey(const GrUniqueKey&);
+ void removeUniqueKey();
void notifyIsPurgeable() const;
void removeScratchKey();
void makeBudgeted();
@@ -291,7 +291,7 @@ private:
static const size_t kInvalidGpuMemorySize = ~static_cast<size_t>(0);
GrScratchKey fScratchKey;
- GrContentKey fContentKey;
+ GrUniqueKey fUniqueKey;
// This is not ref'ed but abandon() or release() will be called before the GrGpu object
// is destroyed. Those calls set will this to NULL.
@@ -127,7 +127,7 @@ public:
/**
* The resource is cached and owned by Skia. Resources with this status may be kept alive
- * by the cache as either scratch or content resources even when there are no refs to them.
+ * by the cache as either scratch or unique resources even when there are no refs to them.
* The cache may release them whenever there are no refs.
*/